import json
import os.path
import requests

from .consts import *


DDRAGON_VERSION_FILENAME = "ddragon_version"
DDRAGON_ITEMS_FILENAME = "ddragon_items.json"

"""
Request from data dragon api to get latest version number and item json. Caches data locally
Return:
    str : latest data dragon version
"""
def _updateDDragonData():
    # check for latest version
    version = requests.get(DDRAGON_VERSIONS_URL).json()[0]
    with open(DDRAGON_VERSION_FILENAME, "w") as fh:
        fh.write(version)

    # update item data cache to latest version
    itemData = requests.get(ITEM_DATA_URL.format(version)).json()
    with open (DDRAGON_ITEMS_FILENAME, "w") as fh:
        json.dump(itemData, fh)

    return version

"""
Checks cache for data dragon version number. If cache doesn't exist call updateDDragon()
Return:
    str : data dragon version
"""
def _checkDDragonData():
    if os.path.isfile(DDRAGON_VERSION_FILENAME):
        with open(DDRAGON_VERSION_FILENAME, "r") as fh:
            version = fh.read()
    else:
        version = _updateDDragonData()

    return version

"""
Params:
    str : champion name
Returns:
    str : url of champion thumbnail
"""
def getChampionThumbnail(champion):
    # TODO: add override for Wukong -> MonkeyKing
    version = _checkDDragonData()
    return CHAMPION_THUMBNAIL_URL.format(version, champion)

"""
Params:
    List[str] : list of item names
Returns:
    Dict[str -> str] : dict that maps item name to item thumbnail url
"""
def getItemThumbnail(items):
    if os.path.isfile(DDRAGON_ITEMS_FILENAME):
        version = _checkDDragonData()
    else:
        version = _updateDDragonData()

    with open(DDRAGON_ITEMS_FILENAME, "r") as fh:
        itemsJson = json.load(fh)["data"]

        itemMap = dict.fromkeys(items)
        for itemId, itemData in itemsJson.items():
            itemName = itemData["name"]
            if itemName in itemMap:
                itemMap[itemName] = ITEM_THUMBNAIL_URL.format(version, itemId)

    return itemMap

"""
Params:
    str : summoner spell name
Returns:
    str : url of summoner spell thumbnail
"""
def getSummonerSpellThumbnail(summonerSpell):
    version = _checkDDragonData()
    return SUMMONER_SPELL_THUMBNAIL_URL.format(version, summonerSpell)


DEFAULT_LEAGUES = [
    "LCK",
    "EU LCS", "LEC",
    "LCS", "NA LCS",
    "LPL",
    "MSC", "MSI", "WCS", "RR"
]

"""
Params:
    Leaguepedia tournament name
Player data format (json)
{
    Team: "SeolHaeOne Prince"
    Role: "Bot"
    FileName: "SP Trigger 2020 Split 2.png"
    ID: "Trigger"
}
"""
PLAYERS_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
    &tables=Tournaments=T,TournamentPlayers=TP,PlayerImages=PI,PlayerRedirects=PR
    &fields=TP.Team,PR.ID,TP.Role,PI.FileName
    &where={}
    &join_on=T.OverviewPage=TP.OverviewPage,TP.Link=PI.Link,TP.Player=PR.AllName
    &order_by=PI.FileName DESC
    &group_by=TP.Player"""

"""
Params:
    Leaguepedia tournament name
Team data format (json)
{
    "Team1":"APK Prince",
    "TeamName":"SeolHaeOne Prince",
    "Short":"SP"
}
"""
TEAMS_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
    &tables=ScoreboardGames=SG,TeamRedirects=TR,Teams=T
    &fields=SG.Team1,TR._pageName=TeamName,T.Short
    &where={}
    &join_on=SG.Team1=TR.AllName,TR._pageName=T._pageName
    &group_by=SG.Team1"""

"""
Params:
    Leaguepedia tournament name
Match schedule data format (json)
{
    DateTime UTC    "2021-01-13 08:00:00"
    Team1   "Gen.G"
    Team2   "KT Rolster"
    BestOf  "3"
    Tab "Week 1"
    DateTime UTC__precision "0"
}
"""
MATCH_SCHEDULE_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
    &tables=MatchSchedule=MS
    &fields=MS.DateTime_UTC,MS.Team1,MS.Team2,MS.BestOf,MS.Tab
    &where={}
    &order_by=MS.DateTime_UTC ASC"""

"""
Params:
    Where clause filtering by L.League_Short
Tournament data format (json)
{
    Name:"Worlds 2020"
    DateStart:"2020-09-25"
    League Short:"WCS"
    DateStart__precision:"1"
}
"""
TOURNAMENTS_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
    &tables=Leagues=L,Tournaments=T
    &fields=T.Name,T.DateStart,L.League_Short
    &where=NOT T.DateStart='' AND {}
    &join_on=L.League=T.League
    &order_by=T.DateStart DESC"""

"""
Params:
    Leaguepedia tournament name
Match data format (json)
{
    "DateTime UTC":"2020-08-07 13:13:00",
    "Patch":"10.15",
    "Team1":"KT Rolster",
    "Team2":"Hanwha Life Esports",
    "Team1Score":"2",
    "Team2Score":"1",
    "UniqueGame":"LCK/2020 Season/Summer Season/Scoreboards/Week 8_4_3",
    "DateTime UTC__precision":"0"
}
"""
MATCHES_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
    &tables=ScoreboardGames=SG
    &fields=SG.DateTime_UTC,SG.Patch,SG.Team1,SG.Team2,SG.Team1Score,SG.Team2Score,SG.UniqueGame
    &where={}
    &order_by=SG.DateTime_UTC DESC"""

"""
Params:
    Where clause filtering by SG.UniqueGame
Game data format (json)
{
    UniqueGame: "LCK/2020 Season/Spring Season/Scoreboards/Week 9_5_1"
    Gamename: "Game 1"
    DateTime UTC: "2020-04-16 09:10:00"
    Gamelength: "25:12"
    MatchHistory: "http://matchhistory.na.leagueoflegends.com/en/#match-details/ESPORTSTMNT03/1351837?gameHash=8d4b64e0e36ce417"
    Winner: "1"
    Team1: "DragonX"
    Team2: "APK Prince"
    Team1Bans: "Illaoi,Trundle,Kalista,Miss Fortune,Ezreal"
    Team2Bans: "Sett,Varus,Senna,Nautilus,Volibear"
    Name: "ikssu"
    Team: "APK Prince"
    Role: "Top"
    Role Number: "1"
    Champion: "Ornn"
    Kills: "1"
    Deaths: "3"
    Assists: "2"
    Gold: "8284"
    CS: "203"
    TeamKills: "7"
    SummonerSpells: "Teleport,Flash"
    Items: "Refillable Potion,Null-Magic Mantle,Mercury's Treads,Doran's Shield,Infernal Mask,Forgefire Cape"
    KeystoneRune: "Unsealed Spellbook"
    FileName: "APK ikssu 2020 Split 1.png"
    DateTime UTC__precision: "0"
}
"""
GAMES_URL = """https://lol.gamepedia.com/api.php?action=cargoquery&format=json&limit=500
    &tables=ScoreboardGames=SG,ScoreboardPlayers=SP,PlayerImages=PI
    &fields=SG.UniqueGame,SG.Gamename,SG.DateTime_UTC,SG.Gamelength,SG.MatchHistory,
    SG.Winner,SG.Team1,SG.Team2,SG.Team1Bans,SG.Team2Bans,
    SP.Name,SP.Team,SP.Role,SP.Role_Number,SP.Champion,SP.Kills,SP.Deaths,SP.Assists,SP.Gold,SP.CS,SP.TeamKills,SP.SummonerSpells,SP.Items,SP.KeystoneRune,PI.FileName
    &where={}
    &join_on=SG.UniqueGame=SP.UniqueGame,SP.Link=PI.Link
    &order_by=SG.UniqueGame ASC,SP.Team,SP.Role_Number ASC
    &group_by=SG.UniqueGame,SP.Name"""

"""
Params:
    FileName provided in game data object
"""
LEAGUEPEDIA_THUMBNAIL_URL = "https://lol.gamepedia.com/Special:Redirect/file/{}"

DDRAGON_VERSIONS_URL = "https://ddragon.leagueoflegends.com/api/versions.json"

"""
Params:
    Data dragon version number
    Champion name
"""
CHAMPION_THUMBNAIL_URL = "http://ddragon.leagueoflegends.com/cdn/{}/img/champion/{}.png"

"""
Params:
    Data dragon version number
"""
ITEM_DATA_URL = "http://ddragon.leagueoflegends.com/cdn/{}/data/en_US/item.json"

"""
Params:
    Data dragon version number
    Item id
"""
ITEM_THUMBNAIL_URL = "http://ddragon.leagueoflegends.com/cdn/{}/img/item/{}.png"

"""
Params:
    Data dragon version number
    Summoner spell name
"""
SUMMONER_SPELL_THUMBNAIL_URL = "http://ddragon.leagueoflegends.com/cdn/{}/img/spell/Summoner{}.png"



from . import leaguepedia


class Tournament:
    def __init__(self, name):
        self.name = name

        self.startDate = ""
        self.league = ""

    def __str__(self):
        return self.name

    def getMatches(self):
        return leaguepedia.getMatches(tournamentName=self.name)

    def getTeams(self, isMapped=False, thumbnailRedirect=False):
        return leaguepedia.getTeams(self.name, isMapped, thumbnailRedirect)

    def getPlayers(self, roleFilter=["Top", "Jungle", "Mid", "Bot", "Support"], thumbnailRedirect=False):
        return leaguepedia.getPlayers(self.name, roleFilter, thumbnailRedirect)

    def getMatchSchedule(self):
        return leaguepedia.getMatchSchedule(self.name)

class Match:
    def __init__(self, _uniqueMatch):
        self._uniqueMatch = _uniqueMatch
        self._uniqueGames = []

        self.dateTime = None
        self.patch = None
        self.teams = (None, None)
        self.scores = (0, 0)

    def __str__(self):
        return "{} {} {}-{} {}\n".format(
            self.dateTime.split(" ")[0], self.teams[0], self.scores[0], self.scores[1], self.teams[1])

    def getGames(self, retrieveImages=False):
        return leaguepedia._getGames(self._uniqueGames, retrieveImages)

class Game:
    def __init__(self, uniqueGame):
        self._uniqueGame = uniqueGame

        self.gameName = None
        self.dateTime = None
        self.duration = None
        self.matchHistory = None

        self.winner = 0
        self.teams = (None, None)
        self.bans = (None, None)
        self.scoreboard = [[None] * 5, [None] * 5]

    def __str__(self):
        return "\t{}: {} vs. {}\n\tWinner: {} in {}\n\t\t{}\n".format(
            self.gameName, self.teams[0], self.teams[1],
            self.teams[self.winner], self.duration,
            "\n\t\t".join([str(self.scoreboard[0][i])+"\t\t"+str(self.scoreboard[1][i]) for i in range(5)]))

    def getScoreline(self, teamIndex, roleIndex):
        return self.scoreboard[teamIndex][roleIndex]

class Scoreline:
    def __init__(self, uniqueGame, player):
        self._uniqueGame = uniqueGame
        self.player = player

        self.role = ""
        self.champion = ""

        self.kills = 0
        self.deaths = 0
        self.assists = 0
        self.kp = 0
        self.gold = 0
        self.cs = 0

        self.summonerSpells = []
        self.items = []
        self.runes = ""
        
        self.assets = {}

    def __str__(self):
        return "{}\t{}\t{}-{}-{}".format(
            self.player, self.champion, self.kills, self.deaths, self.assists)

class Player:
    def __init__(self, name, team, role):
        self.name = name
        self.team = team
        self.role = role
        self.thumbnail = None

    def __str__(self):
        return "{} {}".format(self.team, self.name)

class Team:
    def __init__(self, name, short):
        self.name = name
        self.short = short
        self.thumbnail = None

    def __str__(self):
        return self.short



import re
import json
import requests
import sys

from . import ddragon
from .classes import *
from .consts import *


"""
Filters support equality operators (=, !=, >, <, >=, <=)
e.g. tournamentDate=">2019-08-21" returns all tournaments with dates greater than 2019-08-21

Filters can be either single values 
e.g. tournamentName="LCK 2020 Summer"
or iterables
e.g. tournamentLeague=["LCK", "LCS"]

For iterable filters, the type determines whether AND/OR will be applied
Lists will apply OR to filter elements
e.g. tournamentDate=["2019-08-21", ">2020-01-01"] will return tournaments with tournamentDate = 2019-08-21 OR tournamentDate > 2020-01-01
Tuples will apply AND to filter elements (this is useful for applying tournamentDate range filters)
e.g. tournamentDate=(">2019-08-21", "<=2019-12-01") will return tournaments with dates between 2019-08-21 AND 2019-12-01
"""

def getPlayers(tournamentName, roleFilter=["Top", "Jungle", "Mid", "Bot", "Support"], thumbnailRedirect=False):
    """
    Params:
        tournamentName: str/List[str]/Tuple(str) : filter by tournament names (e.g. LCK 2020 Spring)
        roleFilter: List[str] : (optional) list of player roles to include
        thumbnailRedirect: Bool : (optional) if true, get redirected url for player image
    Returns:
        List[Player] : list of players in tournament
    """
    argsString = _formatArgs(tournamentName, "T.Name")
    url = PLAYERS_URL.format(argsString)
    playersJson = requests.get(url).json()["cargoquery"]
    roles = set(roleFilter)
    
    players = []
    for i in range(len(playersJson)):
        playerJson = playersJson[i]["title"]
        if playerJson["Role"] not in roles:
            # filter roles
            continue
        player = Player(playerJson["ID"], playerJson["Team"], playerJson["Role"])
        player.thumbnail = LEAGUEPEDIA_THUMBNAIL_URL.format(playerJson["FileName"])
        if thumbnailRedirect:
            # get redirected (http 301) image
            try:
                redirect = requests.get(player.thumbnail)
                player.thumbnail = redirect.history[-1].headers["Location"].split("/revision", 1)[0]
                # print progress
                sys.stdout.write("\r")
                sys.stdout.write("getting player thumbnail {}/{}".format(i+1, len(playersJson)))
                sys.stdout.flush()
            except:
                continue
        players.append(player)
    return players

def getTeams(tournamentName, isMapped=False, thumbnailRedirect=False):
    """
    Params:
        tournamentName: str/List[str]/Tuple(str) : filter by tournament names (e.g. LCK 2020 Spring)
        isMapped: Bool : (optional) if true, instead return a dictionary with team names (as they were during the tournament) as the keys
        thumbnailRedirect: Bool : (optional) if true, get redirected url for team image
    Returns:
        List[Team]
    """
    argsString = _formatArgs(tournamentName, "SG.Tournament")
    url = TEAMS_URL.format(argsString)
    teamsJson = requests.get(url).json()["cargoquery"]

    teams = {} if isMapped else []
    for i in range(len(teamsJson)):
        teamJson = teamsJson[i]["title"]
        team = Team(teamJson["TeamName"], teamJson["Short"])
        team.thumbnail = LEAGUEPEDIA_THUMBNAIL_URL.format("_".join(teamJson["TeamName"].split()) + "logo_square.png")
        if thumbnailRedirect:
            # get redirected (http 301) image
            try:
                redirect = requests.get(team.thumbnail)
                team.thumbnail = redirect.history[-1].headers["Location"].split("/revision", 1)[0]
                # print progress
                sys.stdout.write("\r")
                sys.stdout.write("getting team thumbnail {}/{}".format(i+1, len(teamsJson)))
                sys.stdout.flush()
            except:
                continue
        if isMapped: teams[teamJson["Team1"]] = vars(team) 
        else: teams.append(team)
    return teams

def getMatchSchedule(tournamentName):
    """
    Params:
        tournamentName: str/List[str]/Tuple(str) : filter by tournament names (e.g. LCK 2020 Spring)
    Returns:
        Dict[str -> Dict[frozenset -> Dict]]
    """
    argsString = _formatArgs(tournamentName, "MS.ShownName")
    url = MATCH_SCHEDULE_URL.format(argsString)
    schedulesJson = requests.get(url).json()["cargoquery"]

    matchScheduleMap = {}
    for i in range(len(schedulesJson)):
        scheduleJson = schedulesJson[i]["title"]
        date, time = scheduleJson["DateTime UTC"].split()
        if date not in matchScheduleMap: matchScheduleMap[date] = {}

        key = frozenset([scheduleJson["Team1"], scheduleJson["Team2"]])
        matchScheduleMap[date][key] = {
            "time": time,
            "bestOf": scheduleJson["BestOf"],
            "week": scheduleJson["Tab"]
        }
    return matchScheduleMap

def getTournaments(tournamentLeague=DEFAULT_LEAGUES, tournamentName=None, tournamentDate=None):
    """
    Params:
        tournamentLeague: str/List[str]/Tuple(str) : filter by leagues to get tournaments from (e.g. LCS, LCK)
        tournamentName: str/List[str]/Tuple(str) : filter by tournament names (e.g. LCK 2020 Spring)
        tournamentDate: str/List[str]/Tuple(str) : date in the format of yyyy-mm-dd
    Returns:
        Dict[str -> Tournament] : dictionary of tournament names mapped to tournament objects
    """
    argsString = " AND ".join(filter(None, [
        _formatArgs(tournamentLeague, "L.League_Short"),
        _formatArgs(tournamentName, "T.Name"),
        _formatArgs(tournamentDate, "T.DateStart")
        ]))

    url = TOURNAMENTS_URL.format(argsString)
    tournamentsJson = requests.get(url).json()["cargoquery"]

    tournaments = {}
    for i in range(len(tournamentsJson)):
        tournamentJson = tournamentsJson[i]["title"]
        tournament = Tournament(tournamentJson["Name"])
        tournament.startDate = tournamentJson["DateStart"]
        tournament.league = tournamentJson["League Short"]
        tournaments[tournamentJson["Name"]] = tournament

    return tournaments

def getMatches(tournamentName=None, matchDate=None, matchPatch=None, matchTeam=None):
    """
    Params:
        tournamentName: str/List[str]/Tuple(str) : filter by tournament names (e.g. LCK 2020 Spring)
        matchDate: str/List[str]/Tuple(str) : date in the format of yyyy-mm-dd
        matchPatch: str/List[str]/Tuple(str) : game patch the match is played on (e.g. 10.15)
        matchTeam: str/List[str]/Tuple(str)
    Returns:
        List[Match]
    """
    argsString = " AND ".join(filter(None, [
        _formatArgs(tournamentName, "SG.Tournament"),
        _formatDateTimeArgs(matchDate, "SG.DateTime_UTC"),
        _formatArgs(matchPatch, "SG.Patch")
        ]))

    url = MATCHES_URL.format(argsString)
    matchesJson = requests.get(url).json()["cargoquery"]

    matches = []
    uniqueMatchMap = {}
    for i in range(len(matchesJson)):
        matchJson = matchesJson[i]["title"]

        # apply team filter
        if isinstance(matchTeam, str):
            matchTeam = [matchTeam]
        if isinstance(matchTeam, list):
            if matchJson["Team1"] not in matchTeam and matchJson["Team2"] not in matchTeam:
                continue
        elif isinstance(matchTeam, tuple):
            if not set(matchTeam).issubset(set([matchJson["Team1"], matchJson["Team2"]])):
                continue
        
        uniqueMatch = matchJson["UniqueGame"][:-2]
        if uniqueMatch not in uniqueMatchMap:
            match = Match(uniqueMatch)
            match._uniqueGames.append(matchJson["UniqueGame"])
            match.dateTime = matchJson["DateTime UTC"]
            match.patch = matchJson["Patch"]
            match.teams = (matchJson["Team1"], matchJson["Team2"])
            match.scores = (int(matchJson["Team1Score"]), int(matchJson["Team2Score"]))

            matches.append(match)
            uniqueMatchMap[uniqueMatch] = match
        else:
            match = uniqueMatchMap[uniqueMatch]
            match._uniqueGames.append(matchJson["UniqueGame"])
            match.dateTime = matchJson["DateTime UTC"]

    return matches

def _getGames(uniqueGames, retrieveImages=False):
    """
    Params:
        uniqueGames: List[str] : list of strings indicating games to retrieve
        retrieveImages: Bool : indicates whether to retrieve spells, items, runes images from data dragon
    Returns:
        List[Game] : list of game objects retrieved
    """
    url = GAMES_URL.format(_formatArgs(uniqueGames, "SG.UniqueGame"))
    gamesJson = requests.get(url).json()["cargoquery"]

    games = []
    gameMap = {}
    for i in range(len(gamesJson)):
        gameJson = gamesJson[i]["title"]

        uniqueGame = gameJson["UniqueGame"]
        if uniqueGame not in gameMap:
            game = Game(uniqueGame)
            game.gameName = gameJson["Gamename"]
            game.dateTime = gameJson["DateTime UTC"]
            game.duration = gameJson["Gamelength"]
            game.matchHistory = gameJson["MatchHistory"]

            game.winner = int(gameJson["Winner"]) - 1
            game.teams = (gameJson["Team1"], gameJson["Team2"])
            game.bans = (gameJson["Team1Bans"], gameJson["Team2Bans"])

            games.append(game)
            gameMap[uniqueGame] = game

        player = Player(gameJson["Name"], gameJson["Team"], gameJson["Role"])
        player.thumbnail = LEAGUEPEDIA_THUMBNAIL_URL.format(gameJson["FileName"])

        scoreline = Scoreline(uniqueGame, player)
        scoreline.role = gameJson["Role"]
        scoreline.champion = gameJson["Champion"]
        scoreline.kills = int(gameJson["Kills"])
        scoreline.deaths = int(gameJson["Deaths"])
        scoreline.assists = int(gameJson["Assists"])
        scoreline.kp = (scoreline.kills + scoreline.assists) / float(gameJson["TeamKills"])
        scoreline.gold = int(gameJson["Gold"])
        scoreline.cs = int(gameJson["CS"])
        scoreline.summonerSpells = gameJson["SummonerSpells"].split(",")
        scoreline.items = gameJson["Items"].split(",")
        scoreline.runes = gameJson["KeystoneRune"]

        if retrieveImages:
            # retrieve images using data dragon api and populate assets field
            scoreline.assets = ddragon.getItemThumbnail(scoreline.items)
            scoreline.assets[scoreline.champion] = ddragon.getChampionThumbnail(scoreline.champion)
            for summonerSpell in scoreline.summonerSpells:
                scoreline.assets[summonerSpell] = ddragon.getSummonerSpellThumbnail(summonerSpell)

        game = gameMap[uniqueGame]
        gameIndex = game.teams.index(gameJson["Team"])
        roleIndex = int(gameJson["Role Number"]) - 1
        game.scoreboard[gameIndex][roleIndex] = scoreline

    return games

def _formatArgs(args, prefix):
    """
    Params:
        args: str/List[str]/Tuple(str)
        prefix: str
    Returns:
        str : args formatted to be used for leaguepedia query
    """
    if args == None: return None
    delim = " OR "
    if isinstance(args, list): pass
    elif isinstance(args, tuple): delim = " AND "
    else: args = [args]

    def formatArg(arg):
        m = re.search("<=|>=|!=|<|>|=", arg)
        if m == None:
            return "{}='{}'".format(prefix, arg)
        else:
            i = m.span()[1]
            return "{}{}'{}'".format(prefix, arg[:i], arg[i:])

    return "(" + delim.join(formatArg(arg) for arg in args) + ")"

def _formatDateTimeArgs(dateArgs, prefix):
    """
    Helper function to change date strings to datetime strings when formating args
    Params:
        dateArgs: str/List[str]/Tuple(str) : date args in the format of yyyy-mm-dd
        prefix: str
    Returns:
        str : date args in the format of yyyy-mm-dd hh:mm:ss
    """
    if dateArgs == None: return None
    delim = " OR "
    if isinstance(dateArgs, list): pass
    elif isinstance(dateArgs, tuple): delim = " AND "
    else: dateArgs = [dateArgs]

    def formatDateTimeArg(dateArg):
        m = re.search("<=|>=|!=|<|>|=", dateArg)
        if m == None or m.group(0) == "=":
            return "({0}>='{1} 00:00:00' AND {0}<='{1} 23:59:59')".format(prefix, dateArg)
        else:
            i = m.span()[1]
            return "{}{}'{} 00:00:00'".format(prefix, dateArg[:i], dateArg[i:])

    return "(" + delim.join(formatDateTimeArg(dateArg) for dateArg in dateArgs) + ")"



import setuptools

with open("requirements.txt", "r") as fh:
    requirements = fh.read().splitlines()

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="hextech",
    version="1.0.11",
    author="bujustin",
    author_email="bujustin@gmail.com",
    description="A Python framework for accessing League of Legends esports data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bujustin/hextech",
    packages=setuptools.find_packages(),
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
